Search.setIndex({"docnames": ["index"], "filenames": ["index.rst"], "titles": ["agate-dbf 0.2.2"], "terms": {"add": 0, "read": 0, "support": 0, "file": 0, "import": 0, "link": 0, "http": 0, "rtfd": 0, "org": 0, "document": 0, "repositori": 0, "github": 0, "com": 0, "wireservic": 0, "issu": 0, "To": 0, "pip": 0, "For": 0, "detail": 0, "develop": 0, "platform": 0, "see": 0, "us": 0, "monkei": 0, "patch": 0, "pattern": 0, "all": 0, "instanc": 0, "agatedbf": 0, "new": 0, "method": 0, "from_dbf": 0, "exampl": 0, "test": 0, "print": 0, "cl": 0, "path": 0, "encod": 0, "none": 0, "pars": 0, "paramet": 0, "an": 0, "load": 0, "note": 0, "due": 0, "limit": 0, "depend": 0, "you": 0, "can": 0, "pass": 0, "handl": 0, "It": 0, "must": 0, "The": 0, "follow": 0, "individu": 0, "have": 0, "contribut": 0, "code": 0, "excel": 0, "christoph": 0, "groskopf": 0, "No": 0, "longer": 0, "lowercas": 0, "column": 0, "name": 0, "now": 0, "against": 0, "python": 0, "3": 0, "6": 0, "drop": 0, "end": 0, "life": 0, "wa": 0, "septemb": 0, "29": 0, "2017": 0, "remov": 0, "monkeypatch": 0, "upgrad": 0, "requir": 0, "initi": 0, "version": 0, "mit": 0, "copyright": 0, "c": 0, "contributor": 0, "permiss": 0, "herebi": 0, "grant": 0, "free": 0, "charg": 0, "ani": 0, "person": 0, "obtain": 0, "copi": 0, "thi": 0, "softwar": 0, "associ": 0, "deal": 0, "without": 0, "restrict": 0, "includ": 0, "right": 0, "modifi": 0, "merg": 0, "publish": 0, "distribut": 0, "sublicens": 0, "sell": 0, "permit": 0, "whom": 0, "furnish": 0, "do": 0, "so": 0, "subject": 0, "condit": 0, "abov": 0, "notic": 0, "shall": 0, "substanti": 0, "portion": 0, "THE": 0, "IS": 0, "provid": 0, "AS": 0, "warranti": 0, "OF": 0, "kind": 0, "express": 0, "OR": 0, "impli": 0, "BUT": 0, "NOT": 0, "TO": 0, "merchant": 0, "fit": 0, "FOR": 0, "A": 0, "particular": 0, "purpos": 0, "AND": 0, "noninfring": 0, "IN": 0, "NO": 0, "event": 0, "holder": 0, "BE": 0, "liabl": 0, "claim": 0, "damag": 0, "other": 0, "liabil": 0, "whether": 0, "action": 0, "contract": 0, "tort": 0, "otherwis": 0, "aris": 0, "from": 0, "out": 0, "connect": 0, "WITH": 0, "index": 0, "modul": 0, "search": 0, "page": 0}, "objects": {"agatedbf.table": [[0, 0, 1, "", "from_dbf"]]}, "objtypes": {"0": "py:function"}, "objnames": {"0": ["py", "function", "Python function"]}, "titleterms": {"agat": 0, "dbf": 0, "0": 0, "2": 0, "instal": 0, "usag": 0, "api": 0, "author": 0, "changelog": 0, "juli": 0, "7": 0, "2020": 0, "1": 0, "march": 0, "16": 0, "2019": 0, "decemb": 0, "19": 0, "2016": 0, "februari": 0, "5": 0, "licens": 0, "indic": 0, "tabl": 0}, "envversion": {"sphinx.domains.c": 2, "sphinx.domains.changeset": 1, "sphinx.domains.citation": 1, "sphinx.domains.cpp": 6, "sphinx.domains.index": 1, "sphinx.domains.javascript": 2, "sphinx.domains.math": 2, "sphinx.domains.python": 3, "sphinx.domains.rst": 2, "sphinx.domains.std": 2, "sphinx.ext.intersphinx": 1, "sphinx": 56}})